const npmcli = require('../utils/npmcli')

const user = {
  username: 'test',
  password: 'strong',
  email: 'test@strongsoft.net'
}

// data.ok: true
// res.statusCode: 201
test('cli login success', async () => {
  const result = await npmcli.login(user)
  expect(result).toEqual({code: 201, msg: 'success'})
})

// Invalid login The specified login is not valid.: org.couchdb.user:test1 && 403
test('cli login null username', async () => {
  const result = await npmcli.login({
    ...user,
    username: 'test1'
  })
  expect(result).toEqual({code: 403, msg: 'error login'})
})

// Invalid login The specified login is not valid.: org.couchdb.user:test && 403
test('cli login error password', async () => {
  const result = await npmcli.login({
    ...user,
    password: 'strong1'
  })
  expect(result).toEqual({code: 403, msg: 'error login'})
})

// email is not necessary to matching to user, but must to login
test('cli login not match email', async () => {
  const result = await npmcli.login({
    ...user,
    email: 'test1@strongsoft.net'
  })
  expect(result).toEqual({code: 201, msg: 'success'})
})

// Please use a real email address.
// or
// No email address supplied.
test('cli login error email', async () => {
  const error1 = await npmcli.login({
    ...user,
    email: 'test.strongsoft.net'
  })
  const error2 = await npmcli.login({
    ...user,
    email: ''
  })
  expect(error1).toEqual({code: 400, msg: 'illegal email'})
  expect(error2).toEqual({code: 400, msg: 'null email'})
})


