// https://www.npmjs.com/package/execa
const fs = require('fs')
const execa = require('execa')
const jsoner = require('../utils/jsoner')
const user = require('../utils/user')
const { login } = require('../utils/npmcli')
const { NAMESPACE, ADDON_ID, ADDON_URL, ADDON_PATH } = require('../utils/config.js')
const {
  USER_GET,
  USER_SET,
  USER_LOGIN,
  USER_LOGOUT,
  PKG_GET,
  PKG_SET,
  PKG_PUBLISH
} = require('./actions')

var pkg = null

const initSharedData = (share, api) => {
  const cwd = api.getCwd()
  const pro = api.getProject()
  const pkg = jsoner(api.resolve('./package.json'))

  share('test', 'my-test')
  share('user', user.get())
  share('pkg', pkg.get())
}

const initActions = (call, on, api) => {
  on(USER_GET, async params => {
    return await user.get()
  })
  on(USER_SET, async params => {
    return await user.set(params)
  })
  on(USER_LOGIN, async params => {
    const status = await login(params)
    if (status.code === 201) {
      await user.set({
        username: params.username,
        password: params.password,
        _password: params.password
      })
    }
    return status
  })
  on(USER_LOGOUT, async params => {
    return await user.set({
      name: '',
      username: '',
      email: '',
      mobile: '',
      department: '',
      password: '',
      _password: ''
    })
  })

  on(PKG_GET, async () => {
    const pkg = jsoner(api.resolve('./package.json'))
    return await pkg.get()
  })
  on(PKG_SET, async params => {
    const pkg = jsoner(api.resolve('./package.json'))
    return await pkg.set(params)
  })
  on(PKG_PUBLISH, async () => {
    try {
      return await execa('npm publish', [], { 
        cwd: api.getCwd(),
        stdio: ['inherit', 'pipe', 'pipe'],
        shell: true
      })
    } catch (e) {
      // mock stdout & stderr
      return await { stdout: '包发布失败，请根据控制台输出提示检查包内容.', stderr: e.message }
    }
  })
}

module.exports = api => {
  const {
    setSharedData,
    getSharedData,
    removeSharedData,
    watchSharedData,
    unwatchSharedData,
    callAction,
    onAction
  } = api.namespace(NAMESPACE)

  // api.addClientAddon({
  //   id: ADDON_ID,
  //   path: '../../vue-cli-plugin-istrong-ui-addon/dist'
  // })

  if (process.env.VUE_APP_CLI_UI_DEV) {
    // Add dynamic components in dev mode (webpack dashboard & analyzer)
    api.addClientAddon({
      id: ADDON_ID,
      url: ADDON_URL
    })
  } else {
    // Webpack dashboard
    api.addClientAddon({
      id: ADDON_ID,
      path: `${api.getCwd()}/node_modules/${ADDON_PATH}`
    })
  }

  api.addView({
    id: `${NAMESPACE}view`,
    name: NAMESPACE.slice(0, -1),
    icon: 'backup',
    tooltip: '发布'
  })

  initSharedData(setSharedData, api)
  initActions(callAction, onAction, api)
}